// main.h - A progress bar widget
// Copyright (C) 2008  Konrad Twardowski
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

#pragma once

#include <QActionGroup>
#include <QWidget>

using namespace std::chrono;

class Var;

class ProgressBar final: public QWidget {
public:
	enum/* non-class */Size { SmallSize = 2, NormalSize = 3, MediumSize = 6, LargeSize = 9 };
	explicit ProgressBar();
	virtual ~ProgressBar() = default;
	Qt::Alignment alignment() const { return m_alignment; }
	void setAlignment(const Qt::Alignment value, const bool updateConfig, const bool authorize = false);
	void setDemo(const bool active);
	void setHeight(const int value);
	static void updateTaskbar(const double progress, const seconds &seconds);
	void updateValue(const seconds &secsTo, const seconds &totalSecs);
protected:
	virtual void contextMenuEvent(QContextMenuEvent *e) override;
	virtual void mousePressEvent(QMouseEvent *e) override;
	virtual void paintEvent(QPaintEvent *e) override;
private:
	Q_DISABLE_COPY(ProgressBar)
	int m_completeWidth = 0;
	int m_demoWidth = 0;
	Qt::Alignment m_alignment;
	QColor m_demoColor;
	QTimer *m_demoTimer;
	seconds m_secsTo = 0s;
	seconds m_totalSecs = 0s;
	Var *m_alignmentVar;
	Var *m_backgroundColorVar;
	Var *m_foregroundColorVar;
	Var *m_sizeVar;
	void makeIcon(QAction *action, const Qt::Alignment alignment, const int size);
	static void makeRadioButton(QAction *action, QActionGroup *group, const bool checked);
	void setSize(const Size size, const bool authorize = false);
	void updatePalette();

	// event handlers:
	void onDemoTimeout();
	void onSetColor(const bool foreground);
};
